@@ -4,7 +4,7 @@ use Moo::Role;
 
 {
     use version 0.77;
-    $Pod::Readme::Plugin::version::VERSION = version->declare('v1.0.1_06');
+    $Pod::Readme::Plugin::version::VERSION = version->declare('v1.0.1_07');
 }
 
 use ExtUtils::MakeMaker;
@@ -77,6 +77,11 @@ has 'version_run' => (
     lazy    => 1,
 );
 
+around 'depends_on' => sub {
+    my ($orig, $self) = @_;
+    return ($self->version_file, $self->$orig);
+};
+
 sub cmd_version {
     my ( $self, @args ) = @_;
 
